@@ -14,6 +14,7 @@
 #include "kitasubjectview.h"
 #include "kitaboardview.h"
 #include "libkita/threadinfo.h"
+#include "libkita/favoriteboards.h"
 #include "kitathreadtabwidget.h"
 #include "kitasubjecttabwidget.h"
 
@@ -65,6 +66,9 @@ KitaMainWindow::KitaMainWindow()
     // load favorites
     loadFavorites();
 
+    // load favorite boards;
+    loadFavoriteBoards();
+    
     // load completion
     loadCompletion();
 
@@ -84,38 +88,31 @@ KitaMainWindow::KitaMainWindow()
     setAutoSaveSettings();
 
     // allow the view to change the statusbar and caption
-    connect( m_threadView, SIGNAL( signalChangeStatusbar( const QString& ) ),
+    connect( m_threadTab, SIGNAL( signalChangeStatusbar( const QString& ) ),
              SLOT( changeStatusbar( const QString& ) ) );
 
-    connect( m_boardView, SIGNAL( clicked( const Kita::Board* ) ),
-             m_subjectView, SLOT( loadBoard( const Kita::Board* ) ) );
+    connect( m_boardView, SIGNAL( openBoardRequested( const QString&, bool ) ),
+             m_subjectTab, SLOT( loadBoard( const QString&, bool ) ) );
 
-    connect( m_boardView, SIGNAL( openBoardRequested( const Kita::Board*, bool ) ),
-             m_subjectView, SLOT( loadBoard( const Kita::Board*, bool ) ) );
+    connect( m_subjectTab, SIGNAL( showThreadRequested( const Kita::Thread*, bool ) ),
+             m_threadTab, SLOT( showThread( const Kita::Thread*, bool ) ) );
 
-    connect( m_subjectView, SIGNAL( signalShowThread( const Kita::Thread* ) ),
-             m_threadView, SLOT( showThread( const Kita::Thread* ) ) );
+    connect( m_threadTab, SIGNAL( thread( const Kita::Thread* ) ),
+             m_subjectTab, SLOT( updateThread( const Kita::Thread* ) ) );
 
-    // ad-hoc
-    connect( m_subjectView, SIGNAL( signalShowThreadWithNewTab( const Kita::Thread* ) ),
-             m_threadView, SLOT( showThreadWithNewTab( const Kita::Thread* ) ) );
-
-    connect( m_threadView, SIGNAL( thread( const Kita::Thread* ) ),
-             m_subjectView, SLOT( updateThread( const Kita::Thread* ) ) );
-
-    connect( m_threadView, SIGNAL( thread( const Kita::Thread* ) ),
+    connect( m_threadTab, SIGNAL( thread( const Kita::Thread* ) ),
              SLOT( slotThread( const Kita::Thread* ) ) );
 
-    connect( m_threadView, SIGNAL( writeSucceeded() ),
+    connect( m_threadTab, SIGNAL( writeSucceeded() ),
              SLOT( slotWriteSucceeded() ) );
 
-    connect( m_threadView, SIGNAL( showThreadCompleted( const KURL& ) ),
+    connect( m_threadTab, SIGNAL( showThreadCompleted( const KURL& ) ),
              SLOT( setUrl( const KURL& ) ) );
 
-    connect( m_subjectView, SIGNAL( loadBoardCompleted( const KURL& ) ),
+    connect( m_subjectTab, SIGNAL( loadBoardCompleted( const KURL& ) ),
              SLOT( setUrl( const KURL& ) ) );
 
-    connect( m_threadView, SIGNAL( bookmarked( const Kita::Thread*, bool ) ),
+    connect( m_threadTab, SIGNAL( bookmarked( const Kita::Thread*, bool ) ),
              SLOT( bookmark( const Kita::Thread*, bool ) ) );
 
     connect( m_urlLine, SIGNAL( returnPressed() ),
@@ -139,6 +136,8 @@ KitaMainWindow::~KitaMainWindow()
 
     saveCompletion();
 
+    saveFavoriteBoards();
+    
     saveFavorites();
 
     saveCache();
@@ -180,7 +179,7 @@ void KitaMainWindow::setupActions()
     KStdAction::openNew( this, SLOT( fileNew() ), actionCollection() );
     KStdAction::quit( this, SLOT( close() ), actionCollection() );
     KStdAction::copy( this, SLOT( slotEditCopy() ), actionCollection() );
-    KStdAction::find( this, SLOT( slotEditFind() ), actionCollection() );
+    KStdAction::find( m_threadTab, SLOT( focusSearchCombo() ), actionCollection() );
 
     m_toolbarAction = KStdAction::showToolbar( this,
                       SLOT( optionsShowToolbar() ),
@@ -232,8 +231,8 @@ void KitaMainWindow::setupActions()
 
     new KAction( i18n( "Reload" ),
                  KStdAccel::reload(),
-                 this,
-                 SLOT( slotViewReload() ),
+                 m_threadTab,
+                 SLOT( reloadThread() ),
                  actionCollection(),
                  "reload" );
 
@@ -251,7 +250,7 @@ void KitaMainWindow::slotUrlLine()
 {
     QString text = m_urlLine->text();
     QString datURL = Kita::threadToDat( text );
-    m_threadView->showThread( datURL );
+    m_threadTab->showThread( datURL );
 }
 
 void KitaMainWindow::writeConfig( KConfig* config )
@@ -416,7 +415,7 @@ void KitaMainWindow::windowMenuAboutToShow()
 
 void KitaMainWindow::windowCloseTab()
 {
-    m_threadView->closeCurrentTab();
+    m_threadTab->closeCurrentTab();
 }
 
 void KitaMainWindow::settingsMenuAboutToShow()
@@ -464,17 +463,16 @@ void KitaMainWindow::setupView()
 {
     KDockWidget * mainDock;
     mainDock = createDockWidget( "main", 0L, 0L, i18n( "main" ) );
-    m_threadView = new KitaThreadTabWidget( mainDock );
-    mainDock->setWidget( m_threadView );
+    m_threadTab = new KitaThreadTabWidget( mainDock );
+    mainDock->setWidget( m_threadTab );
     mainDock->setDockSite( KDockWidget::DockFullSite );
     mainDock->setEnableDocking( KDockWidget::DockNone );
-    connect( m_threadView, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
+    connect( m_threadTab, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
              SLOT( slotOpenURLRequest( const KURL&, const KParts::URLArgs& ) ) );
 
     m_subjectDock = createDockWidget( "subject", 0L, 0L, i18n( "subject" ) );
-    //  m_subjectView = new KitaSubjectView( m_subjectDock );
-    m_subjectView = new KitaSubjectTabWidget( m_subjectDock );
-    m_subjectDock->setWidget( m_subjectView );
+    m_subjectTab = new KitaSubjectTabWidget( m_subjectDock );
+    m_subjectDock->setWidget( m_subjectTab );
     m_subjectDock->setDockSite( KDockWidget::DockFullSite );
 
     m_boardDock = createDockWidget( "board", 0L, 0L, i18n( "board" ) );
@@ -523,14 +521,14 @@ void KitaMainWindow::saveCache()
 void KitaMainWindow::setFont( const QFont& font )
 {
     KitaConfig::setFont( font );
-    m_subjectView->setFont( font );
+    m_subjectTab->setFont( font );
     m_boardView->setFont( font );
 }
 
 void KitaMainWindow::setThreadFont( const QFont& font )
 {
     KitaConfig::setThreadFont( font );
-    m_threadView->setFont( font );
+    m_threadTab->setFont( font );
 }
 
 void KitaMainWindow::slotWriteSucceeded()
@@ -549,7 +547,7 @@ void KitaMainWindow::bookmark( const Kita::Thread* thread, bool on )
     FavoriteThreads* favorite = FavoriteThreads::getInstance();
 
     if ( on ) {
-        favorite->insert( thread );
+        favorite->insert( thread->datURL() );
     } else {
         favorite->remove( thread->datURL() );
     }
@@ -560,7 +558,11 @@ void KitaMainWindow::loadFavorites()
     QString favoritesConfigPath = locateLocal( "appdata", "favorites.xml" );
     QFile file( favoritesConfigPath );
     if ( file.open( IO_ReadOnly ) ) {
-        FavoriteThreads::fromXml( QString::fromUtf8( file.readAll().data() ) );
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+        
+        QString xml = stream.read();
+        FavoriteThreads::readFromXML( xml );
     }
 }
 
@@ -571,7 +573,7 @@ void KitaMainWindow::saveFavorites()
     if ( file.open( IO_WriteOnly ) ) {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
-        stream << FavoriteThreads::getInstance() ->toXml();
+        stream << FavoriteThreads::getInstance() ->toXML();
     }
 }
 
@@ -628,6 +630,30 @@ void KitaMainWindow::saveAsciiArt()
     }
 }
 
+void KitaMainWindow::loadFavoriteBoards()
+{
+    QString configPath = locateLocal( "appdata", "favorite_boards.xml" );
+    QFile file( configPath );
+    if ( file.open( IO_ReadOnly ) ) {
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+        
+        QString xml = stream.read();
+        Kita::FavoriteBoards::readFromXML( xml );
+    }
+}
+
+void KitaMainWindow::saveFavoriteBoards()
+{
+    QString configPath = locateLocal( "appdata", "favorite_boards.xml" );
+    QFile file( configPath );
+    if ( file.open( IO_WriteOnly ) ) {
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+        stream << Kita::FavoriteBoards::toXML();
+    }
+}
+
 void KitaMainWindow::slotThread( const Kita::Thread* thread )
 {
     setCaption( thread->name() );
@@ -643,14 +669,4 @@ void KitaMainWindow::slotEditCopy()
     }
 }
 
-void KitaMainWindow::slotEditFind()
-{
-    m_threadView->focusSearchCombo();
-}
-
-void KitaMainWindow::slotViewReload()
-{
-    m_threadView->reloadThread();
-}
-
 #include "kita.moc"
