@@ -101,8 +101,6 @@ private slots:
     void settingsMenuAboutToShow();
     void settingsShowMailAddress();
     void slotEditCopy();
-    void slotEditFind();
-    void slotViewReload();
 
     void changeStatusbar( const QString& text );
     void changeCaption( const QString& text );
@@ -116,9 +114,9 @@ private slots:
     void slotThread( const Kita::Thread* thread );
 
 private:
-    KitaThreadTabWidget* m_threadView;
+    KitaThreadTabWidget* m_threadTab;
     KitaBoardView* m_boardView;
-    KitaSubjectTabWidget* m_subjectView;
+    KitaSubjectTabWidget* m_subjectTab;
     KLineEdit* m_urlLine;
 
     KPrinter *m_printer;
@@ -138,6 +136,8 @@ private:
     void saveCache();
     void loadFavorites();
     void saveFavorites();
+    void loadFavoriteBoards();
+    void saveFavoriteBoards();
     void loadCompletion();
     void saveCompletion();
     void loadAsciiArt();
