@@ -61,6 +61,12 @@ void KitaSubjectTabWidget::loadBoard( const Kita::Board* board, bool withNewTab
     showPage( m_latestView );
 }
 
+void KitaSubjectTabWidget::loadBoard( const QString& boardURL, bool withNewTab )
+{
+    Kita::Board* board = Kita::Board::getByURL( boardURL );
+    loadBoard( board, withNewTab );
+}
+
 void KitaSubjectTabWidget::updateThread( const Kita::Thread* thread )
 {
     for ( int i = 0; i < count(); i++ ) {
@@ -76,10 +82,8 @@ void KitaSubjectTabWidget::updateThread( const Kita::Thread* thread )
 
 void KitaSubjectTabWidget::connectSignals( Kita::ThreadListView* view )
 {
-    connect( view, SIGNAL( signalShowThread( const Kita::Thread* ) ),
-             this, SIGNAL( signalShowThread( const Kita::Thread* ) ) );
-    connect( view, SIGNAL( signalShowThreadWithNewTab( const Kita::Thread* ) ),
-             this, SIGNAL( signalShowThreadWithNewTab( const Kita::Thread* ) ) );
+    connect( view, SIGNAL( showThreadRequested( const Kita::Thread*, bool ) ),
+             this, SIGNAL( showThreadRequested( const Kita::Thread*, bool ) ) );
 }
 
 void KitaSubjectTabWidget::slotCurrentChanged( QWidget* widget )
