@@ -45,8 +45,8 @@ KitaSubjectView::KitaSubjectView( QWidget* parent, const char* name )
 {
     connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
              SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
-    connect( subjectList, SIGNAL( clicked( QListViewItem* ) ),
-             SLOT( loadThread( QListViewItem* ) ) );
+    connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
+             SLOT( slotMouseButtonClicked( int, QListViewItem* ) ) );
     connect( subjectList, SIGNAL( returnPressed( QListViewItem* ) ),
              SLOT( loadThread( QListViewItem* ) ) );
     connect( ReloadButton, SIGNAL( clicked() ),
@@ -83,13 +83,13 @@ void KitaSubjectView::loadThread( QListViewItem* item )
 
     Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
 
-    emit signalShowThread( thread );
+    emit showThreadRequested( thread, false );
 }
 
 void KitaSubjectView::loadBoard( const Kita::Board* board )
 {
     setActiveWindow();
-    topLevelWidget()->raise();
+    topLevelWidget() ->raise();
 
     // reset member variables.
     // FIXME: FavoriteListView::update()˥ԡ
@@ -200,7 +200,7 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
         KRun::runURL( thread->url(), "text/html" );
         break;
     case 1:
-        emit signalShowThreadWithNewTab( thread );
+        emit showThreadRequested( thread, true );
         break;
     case 2:
         clipboard->setText( thread->name() + "\n" + thread->url() );
@@ -216,3 +216,21 @@ void KitaSubjectView::slotReloadButton()
         loadBoard( m_board );
     }
 }
+
+void KitaSubjectView::slotMouseButtonClicked( int button, QListViewItem* item )
+{
+    if ( ! item ) return ;
+
+    KURL datURL = item->text( Col_DatURL );
+
+    Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
+
+    switch ( button ) {
+    case MidButton:
+        emit showThreadRequested( thread, true );
+        break;
+    case LeftButton:
+        emit showThreadRequested( thread, false );
+        break;
+    }
+}
