@@ -46,11 +46,11 @@ private slots:
     void loadThread( QListViewItem* item );
     void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
     void slotReloadButton();
+    void slotMouseButtonClicked( int, QListViewItem* );
 
 signals:
     void loadBoardCompleted( const KURL& );
-    void signalShowThread( const Kita::Thread* thread );
-    void signalShowThreadWithNewTab( const Kita::Thread* thread );
+    void showThreadRequested( const Kita::Thread* thread, bool withNewTab );
 };
 
 #endif
