@@ -11,10 +11,13 @@
 
 #include "thread.h"
 #include "qcp932codec.h"
+#include "cache.h"
 
 #include <config.h>
 
 #include <sys/stat.h>
+#include <stdlib.h>
+#include <unistd.h>
 
 #include <kurl.h>
 #include <kglobal.h>
@@ -31,56 +34,6 @@
 
 using namespace Kita;
 
-QString Access::cacheDir( const KURL& url )
-{
-    QString dir;
-    if ( url.protocol() == "k2ch" ) {
-        dir = KGlobal::dirs() ->saveLocation( "cache", "k2ch" );
-    } else {
-        dir = KProtocolManager::cacheDir();
-    }
-    if ( dir[ dir.length() - 1 ] != '/' )
-        dir += "/";
-
-    return dir;
-}
-
-QString Access::cacheSubDir( const QString& host )
-{
-    int l = host.length();
-    for ( int i = 0; i < l; i++ ) {
-        if ( host[ i ].isLetter() && ( host[ i ] != 'w' ) ) {
-            return QString( host[ i ] );
-        }
-    }
-    return "0";
-}
-
-QString Access::hashString( const KURL& url )
-{
-    unsigned long hash = 0x00000000;
-    QCString u = url.url().latin1();
-    for ( int i = u.length(); i--; ) {
-        hash = ( hash * 12211 + u[ i ] ) % 2147483563;
-    }
-
-    QString ret;
-    ret.sprintf( "%08lx", hash );
-
-    return ret;
-}
-
-// copied from http.cc
-QString Access::getCachePath( const KURL& url )
-{
-    QString path = url.path();
-    path.replace( QChar( '/' ), QChar( '_' ) );
-
-    QString host = url.host().lower();
-
-    return cacheDir( url ) + cacheSubDir( host ) + "/" + host + path + '_' + hashString( url );
-}
-
 bool Access::readCacheHeader( FILE* fs, const KURL& url )
 {
     QFile file;
@@ -148,7 +101,7 @@ bool Access::readCacheHeader( FILE* fs, const KURL& url )
 // å夬ʤȤ0֤
 QCString Access::getCacheData( const KURL& url )
 {
-    QString cachePath = getCachePath( url );
+    QString cachePath = Kita::Cache::getPath( url );
 
     FILE *fs = fopen( QFile::encodeName( cachePath ), "r" );
     if ( !fs ) {
@@ -177,7 +130,7 @@ QCString Access::getCacheData( const KURL& url )
 // partial dataäƤΤǤ񤭴롣
 void Access::writeCacheData( const KURL& url )
 {
-    QString cachePath = getCachePath( url );
+    QString cachePath = Kita::Cache::getPath( url );
 
     FILE *fs = fopen( QFile::encodeName( cachePath ), "r+" );
     if ( !fs ) {
@@ -209,7 +162,7 @@ QString Access::get()
     m_orgData = getCacheData( m_thread->datURL() );
 
     // copy original cache file
-    QString cachePath = getCachePath( m_thread->datURL() );
+    QString cachePath = Kita::Cache::getPath( m_thread->datURL() );
     QString backupPath = cachePath + ".kita_backup";
     KIO::NetAccess::copy( cachePath, backupPath );
 
@@ -260,7 +213,7 @@ void Access::enter_loop()
 void Access::slotRedirection( KIO::Job *, const KURL & newURL )
 {
     // datƤȻפΤǥå򸵤᤹
-    QString cachePath = getCachePath( m_thread->datURL() );
+    QString cachePath = Kita::Cache::getPath( m_thread->datURL() );
     QString backupPath = cachePath + ".kita_backup";
     KIO::NetAccess::copy( backupPath, cachePath );
     KIO::NetAccess::del( backupPath );
