@@ -20,43 +20,27 @@
 
 #include "thread.h"
 
+class QDomNode;
+
 /**
 @author Hideki Ikemoto
 */
 class FavoriteThreads{
   static FavoriteThreads* instance;
-  QDict<Kita::Thread> m_threadDict;
+  QValueList<QString> m_threadList;
   FavoriteThreads();
   ~FavoriteThreads();
 public:
-//  typedef QDict<Kita::Thread>::const_iterator const_iterator;
   static FavoriteThreads* getInstance();
-  void insert( const Kita::Thread* thread );
+  void insert( const QString& datURL );
   void remove( const QString& datURL );
   bool contains( const QString& datURL ) const;
-  const QDict<Kita::Thread>& threads() const { return m_threadDict; };
-  static FavoriteThreads* fromXml( const QString& xml );
-  const QString toXml() const;
-
-  static bool test();
-};
-
-class FavoritesXmlParser : public QXmlDefaultHandler
-{
-  bool m_inFavorites;
-  bool m_inThread;
-  bool m_isValid;
-  QString m_characters;
-  QPtrList<Kita::Thread> m_threadList;
-  Kita::ThreadXmlParser* m_threadParser;
-public:
-  FavoritesXmlParser() : m_inFavorites(false), m_inThread(false), m_isValid(false) {};
-  ~FavoritesXmlParser() {};
-  bool startElement( const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts );
-  bool endElement( const QString& namespaceURI, const QString& localName, const QString& qName );
-  bool characters( const QString& ch );
-  bool isValid() const { return m_isValid; }
-  QPtrList<Kita::Thread> getThreads() const { return m_threadList; }
+  const QValueList<QString> threadList() const;
+  const QString toXML() const;
+  static bool readFromXML( const QString& xml );
+  static void processThreadNode( QDomNode& node );
+  static bool processBoardNode( QDomNode& node );
+  static void replace( QString fromURL, QString toURL );
 };
 
 #endif
