@@ -47,8 +47,17 @@ QString Kita::datToThread( const QString& datURL )
     KURL newURL;
     newURL.setProtocol( protocol );
     newURL.setHost( host );
-    newURL.addPath( QString( "/test/read.cgi/%2/%3/" )
-                    .arg( board ).arg( datName ) );
+
+    // FIXME: TOOOOOOOOOOOOOOOOOOOOOO ugly.
+    QRegExp host_machibbs( ".*\\.machi\\.to" );
+    if ( host_machibbs.search( host ) != -1 ) {
+        newURL.addPath( "/bbs/read.pl" );
+        newURL.addQueryItem( "BBS", board );
+        newURL.addQueryItem( "KEY", datName );
+    } else {
+        newURL.addPath( QString( "/test/read.cgi/%2/%3/" )
+                        .arg( board ).arg( datName ) );
+    }
 
     return newURL.url();
 }
