@@ -41,7 +41,7 @@ void BoardTest::testID()
 void BoardTest::testName()
 {
     CPPUNIT_ASSERT_EQUAL( QString( "Linux" ), m_share1->name() );
-    CPPUNIT_ASSERT_EQUAL( QString( "U**x" ), m_share2->name() );
+    CPPUNIT_ASSERT_EQUAL( QString( "Unix" ), m_share2->name() );
     CPPUNIT_ASSERT_EQUAL( QString( "Unix" ), m_share3->name() );
     CPPUNIT_ASSERT_EQUAL( QString::null, m_null->name() );
 }
@@ -67,3 +67,26 @@ void BoardTest::testURL()
                           m_share3->url() );
     CPPUNIT_ASSERT_EQUAL( QString::null, m_null->url() );
 }
+
+void BoardTest::testStaticName()
+{
+    CPPUNIT_ASSERT_EQUAL( QString( "Linux" ), Kita::Board::getName( "http://pc.2ch.net/linux/" ) );
+    CPPUNIT_ASSERT_EQUAL( QString( "Unix" ), Kita::Board::getName( "http://pc.2ch.net/unix/" ) );
+    CPPUNIT_ASSERT_EQUAL( QString::null, Kita::Board::getName( QString::null ) );
+}
+
+void BoardTest::testReplace()
+{
+    Kita::Board::replace( QString( "http://pc.2ch.net/linux/" ), QString( "http://pc3.2ch.net/linux/" ) );
+    Kita::Board* board = Kita::Board::getByURL( "http://pc3.2ch.net/linux/" );
+    
+    CPPUNIT_ASSERT_EQUAL( QString( "linux" ), board->id() );
+    CPPUNIT_ASSERT_EQUAL( QString( "Linux" ), board->name() );
+    CPPUNIT_ASSERT_EQUAL( QString( "http://pc3.2ch.net/linux/subject.txt" ),
+                          board->subjectTxtURL().url() );
+    CPPUNIT_ASSERT_EQUAL( QString( "http://pc3.2ch.net/linux/"),
+                          board->url() );
+    CPPUNIT_ASSERT_EQUAL( QString( "Linux" ), Kita::Board::getName( "http://pc3.2ch.net/linux/" ) );
+
+    Kita::Board::replace( QString( "http://pc3.2ch.net/linux/" ), QString( "http://pc.2ch.net/linux/" ) );
+}
