@@ -18,6 +18,7 @@
 #include "boardtest.h"
 #include "misctest.h"
 #include "favoritethreadstest.h"
+#include "favoriteboardstest.h"
 
 int main( int argc, char* argv[] )
 {
@@ -30,6 +31,7 @@ int main( int argc, char* argv[] )
   runner.addTest( BoardTest::suite() );
   runner.addTest( MiscTest::suite() );
   runner.addTest( FavoriteThreadsTest::suite() );
+  runner.addTest( FavoriteBoardsTest::suite() );
   runner.run( "" );
   return 0;
 }
