@@ -52,11 +52,9 @@ namespace Kita
         const QString boardURL() const;
         const QString boardID() const;
 
-        const QString toXmlFragment() const;
-        static Thread* fromXml( const QString& xml );
-
         static Thread* getByURL( const QString& datURL );
         static void setName( const QString& datURL, const QString& threadName );
+        static void replace( const QString& fromURL, const QString& toURL );
     private:
         QString m_datURL;
         QString m_threadName;
@@ -69,36 +67,6 @@ namespace Kita
         NullThread();
         ~NullThread();
     };
-
-    class ThreadXmlParser : public QXmlDefaultHandler
-    {
-    public:
-        ThreadXmlParser();
-        ~ThreadXmlParser() {};
-        bool startElement( const QString& namespaceURI,
-                           const QString& localName,
-                           const QString& qName,
-                           const QXmlAttributes& atts );
-        bool endElement( const QString& namespaceURI,
-                         const QString& localName,
-                         const QString& qName );
-        bool characters( const QString& ch );
-        bool isValid() const { return m_isValid; }
-        Thread* getThread() const { return m_thread; }
-
-    private:
-        QString m_datUrlStr;
-        QString m_threadName;
-        int m_resNum;
-        Thread* m_thread;
-        BoardXmlParser* m_boardParser;
-
-        QString m_characters;
-
-        bool m_inBoard;
-        bool m_isValid;
-        bool m_inThread;
-    };
 };
 
 #endif
