@@ -199,7 +199,7 @@ void KitaThreadView::update( const QString& result )
                      "color: %3; "
                      "background-color: %4\">" )
             .arg( KitaConfig::threadFont().pointSize() )
-            .arg( KitaConfig::font().family() )
+            .arg( KitaConfig::threadFont().family() )
             .arg( KitaConfig::threadColor().name() )
             .arg( KitaConfig::threadBackgroundColor().name() );
 
