@@ -30,7 +30,7 @@ template <class T> class QValueStack;
 
 namespace Kita
 {
-    class ThreadAccess;
+    class Access;
     class PopupTextBrowser;
     class ResPopup;
 };
@@ -69,7 +69,7 @@ protected slots:
     void slotOpenURLRequest( const KURL&, const KParts::URLArgs& );
 
 private:     // Private attributes
-    Kita::ThreadAccess* m_access;
+    Kita::Access* m_access;
     Kita::Thread* m_thread;
     KitaHTMLPart* m_threadPart;
     Kita::PostInfo m_postInfo;
