@@ -202,8 +202,9 @@ void KitaWriteDialog::slotPostFinished( KIO::Job* job )
 void KitaWriteDialog::reject()
 {
     switch ( QMessageBox::warning( this, "Kita",
-                                   "If you close this dialog, you will lose text.\n"
-                                   "Do you want to close?", QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default ) ) {
+                                   i18n( "If you close this dialog, you will lose text.\n"
+                                         "Do you want to close?" ),
+                                   QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default ) ) {
     case QMessageBox::Ok:
         KitaWriteDialogBase::reject();
         break;
