@@ -20,9 +20,11 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qlistbox.h>
+#include <qmessagebox.h>
 
 #include "kitafontprefbase.h"
 #include "kitaconfig.h"
+#include "debugprefbase.h"
 
 using namespace Kita;
 
@@ -47,6 +49,9 @@ KitaPreferences::KitaPreferences()
 
     QFrame * asciiArtFrame = addPage( i18n( "AsciiArt" ), i18n( "AsciiArt" ) );
     m_asciiArtPage = new Kita::AsciiArtPrefPage( asciiArtFrame );
+
+    QFrame * debugFrame = addPage( i18n( "Debug" ), i18n( "Debug" ) );
+    m_debugPage = new DebugPrefPage( debugFrame );
 }
 
 KitaFontPrefPage::KitaFontPrefPage( QWidget* parent )
@@ -161,6 +166,37 @@ void KitaColorPrefPage::slotChangeButtonClicked()
     }
 }
 
+DebugPrefPage::DebugPrefPage( QWidget* parent )
+        : DebugPrefBase( parent )
+{
+    connect( replaceButton, SIGNAL( clicked() ), SLOT( replace() ) );
+}
+
+void DebugPrefPage::replace()
+{
+    QString fromURL = fromURLLine->text();
+    QString toURL = toURLLine->text();
+
+    if ( toURL.find( fromURL ) == 0 ) {
+        QMessageBox::critical( this, i18n( "replace" ),
+                               i18n( "'To' URL must not contain 'From' URL." ) );;
+        return ;
+    }
+
+    if ( QMessageBox::warning( this, i18n( "replace" ),
+                               i18n( "This tool may possibly break thread's info.\n"
+                                     "Please create backups of '~/.kde/share/apps/kita/cache'\n"
+                                     "and '~/.kde/share/apps/kita/favorites.xml' before performing.\n"
+                                     "Are you ready?" ), QMessageBox::Ok,
+                               QMessageBox::Cancel | QMessageBox::Default | QMessageBox::Escape ) == QMessageBox::Ok ) {
+        FavoriteThreads::replace( fromURL, toURL );
+        Kita::Thread::replace( fromURL, toURL );
+        KitaThreadInfo::replace( fromURL, toURL );
+
+        QMessageBox::information( this, i18n( "replace" ), i18n( "Complete." ) );
+    }
+}
+
 AsciiArtPrefPage::AsciiArtPrefPage( QWidget* parent )
         : AsciiArtPrefBase( parent )
 {
